MotionTabBar class

Inheritance

Constructors

MotionTabBar({TextStyle? textStyle, Color? tabIconColor = Colors.black, double? tabIconSize = 24, Color? tabIconSelectedColor = Colors.white, double? tabIconSelectedSize = 24, Color? tabSelectedColor = Colors.black, Color? tabBarColor = Colors.white, double? tabBarHeight = 65, double? tabSize = 60, Function? onTabItemSelected, required String initialSelectedTab, required List<String?> labels, List<IconData>? icons, bool useSafeArea = true, List<Widget?>? badges, MotionTabBarController? controller})

Properties

badges → List<Widget?>?
final
controller → MotionTabBarController?
final
hashCode → int
The hash code for this object.
no setterinherited
icons → List<IconData>?
final
initialSelectedTab → String
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels → List<String?>
final
onTabItemSelected → Function?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabBarColor → Color?
final
tabBarHeight → double?
final
tabIconColor → Color?
final
tabIconSelectedColor → Color?
final
tabIconSelectedSize → double?
final
tabIconSize → double?
final
tabSelectedColor → Color?
final
tabSize → double?
final
textStyle → TextStyle?
final
useSafeArea → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MotionTabBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited